<?php
/* Przykład na podstawie: Thompson, Eide-Goodman, Nowicki, Cove, PHP5 Programowanie zaawansowane, Helion 2005 */
class Database
{
	private $connection;
	
	public function __construct( $configfile='database_config.php' )
	{
		if ( !file_exists( $configfile ) ) throw new Exception( "Brak pliku konfiguracyjnego" );
		require( $configfile );
  		$this->connection = pg_connect( "host=$server dbname=$database user=$user password=$password" );
  		if ( !is_resource( $this->connection ) ) throw new Exception( pg_last_error( $this->connection ) ); 
	}
	
	function select( $sql )
	{
  		$res=pg_query( $this->connection, $sql );
  		if ( !is_resource( $res ) ) throw new Exception( pg_last_error( $this->connection ) );
		$t=array();
		while ( $row=pg_fetch_assoc( $res ) )
		{
			$t[]=$row;
		}
		return $t;
	}
	
	function insert( $table, $row )
	{
		$fields=array_keys( $row );
		$values=array_values( $row );
		$escValues=array();
		foreach( $values as $val )
		{
			if ( !is_numeric( $val ) )
			{
				$val="'".pg_escape_string( $val )."'";	
			}
			$escValues[]=$val;
		}
		$sql="INSERT INTO $table (".join(',',$fields).') VALUES ('.join(',',$escValues ).")";
		$res=pg_query( $this->connection, $sql );
		if ( !is_resource( $res ) ) throw new Exception( pg_last_error( $this->connection ) );
		return pg_affected_rows( $res );
	}
	
	function update( $table, $fields, $condition )
	{
		$updates=array();
		foreach ( $fields as $field => $value )
		{
			if ( !is_numeric( $value ) )
			{
				$value="'".pg_escape_string( $value )."'";
			}
			$updates[]="$field=$value";
		}
		$where=array();
		foreach ( $condition as $field => $value )
		{
			if ( !is_numeric( $value ) )
			{
				$value="'".pg_escape_string( $value )."'";
			}
			$where[]="$field=$value";
		}
		$sql="UPDATE $table SET ".implode( ",", $updates )." WHERE ".implode( ' AND ', $where );
		$res=pg_query( $this->connection, $sql );
		if ( !is_resource( $res ) ) throw new Exception( pg_last_error( $this->connection ) );
		return pg_affected_rows( $res );		
	}
	
	function delete( $table, $condition )
	{
		$where=array();
		foreach ( $condition as $field => $value )
		{
			if ( !is_numeric( $value ) )
			{
				$value="'".pg_escape_string( $value )."'";
			}
			$where[]="$field=$value";
		}
		$sql="DELETE FROM $table ";
		if ( count( $where )>0 ) $sql.=" WHERE ".implode( ' AND ', $where );
		$res=pg_query( $this->connection, $sql );
		if ( !is_resource( $res ) ) throw new Exception( pg_last_error( $this->connection ) );
		return pg_affected_rows( $res );				
	}

	function __destruct()
	{
  		pg_close( $this->connection );
	}
}
?>
<?php
  $dane = array(
  	array( 'id'=>1, 'imie'=>'Adam', 'nazwisko'=>'Waleczek', 'data_ur'=>'1977-01-02', 'pesel'=>'77010223221', 'adres'=>'ul. Kamieńskiego 20, Wrocław' ),
  	array( 'id'=>2, 'imie'=>'Maria', 'nazwisko'=>'Król', 'data_ur'=>'1972-04-01', 'pesel'=>'72040167843', 'adres'=>'ul. Kromera 2, Wrocław' ),
  	array( 'id'=>3, 'imie'=>'Ewa', 'nazwisko'=>'Samiec', 'data_ur'=>'1980-10-10', 'pesel'=>'80101098734', 'adres'=>'ul. Reja 18, Wrocław' ),
  	array( 'id'=>4, 'imie'=>'Adam', 'nazwisko'=>'Wysocki', 'data_ur'=>'1970-11-11', 'pesel'=>'70111198264' )
  );

  try
  {
  	$db=new Database();
  	$db->delete( "osoba", array() );
  	for ( $i=0; $i<4; $i++ )
  	{
		$db->insert( "osoba", $dane[$i] );
  	}
  	$db->update( "osoba", array( 'nazwisko'=>'Samica'), array( 'nazwisko'=> 'Samiec' ) );
  	$db->delete( "osoba", array( 'nazwisko'=>'Wysocki' ) );
  	$db=null;
  }
  catch ( Exception $e )
  {
  	echo $e->getMessage();
  }
?>
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
<html>
<head>
<title>Tworzenie tabeli</title>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8">
</head>

<body>

Dane tej tabeli:
<table border="1">
<?php
  try
  {
  	$db=new Database();
  	$result=$db->select( "select * from osoba" );
  	foreach ( $result as $row )
  	{
	  	echo "<tr>";
		foreach ( $row as $col ) echo "<td>$col</td>";
		echo "</tr>";  	
  	}
  	$db=null;
  }
  catch( Exception $e )
  {
  	echo $e->getMessage();
  }
?> 
</body>
</html>